@@ -194,10 +194,8 @@ class SSHClient(object):
         log.info(f" {self.__ip}:{self.__port} | begin to run cmd:{cmd}.")
         try:
             if promt_response:
-                channel = self.__ssh.exec_command('bash', get_pty=True)[0].channel
-                channel.set_window_size(200, 200)
-                # channel = self.__ssh.get_transport().open_session()
-                # channel.get_pty()  # 获取虚拟终端
+                channel = self.__ssh.get_transport().open_session()
+                channel.get_pty(width=80, height=100)  # 获取虚拟终端
                 channel.exec_command(cmd)
                 output = ""
                 begin=datetime.now()
@@ -228,8 +226,8 @@ class SSHClient(object):
                 return_code = channel.recv_exit_status()
                 return ExecResult(return_code, output, stderr)
             else:
-                channel = self.__ssh.exec_command('bash', get_pty=True)[0].channel
-                channel.set_window_size(200, 200)
+                channel = self.__ssh.get_transport().open_session()
+                channel.get_pty(width=80, height=100)  # 获取虚拟终端
                 stdin, stdout, stderr = channel.exec_command(cmd,timeout=timeout)
                 exit_status = stdout.channel.recv_exit_status()
                 std_output = stdout.read().decode()
